/****************************************************************************
** Meta object code from reading C++ file 'UIExtraDataManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIExtraDataManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18UIExtraDataManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIExtraDataManager::qt_create_metaobjectdata<qt_meta_tag_ZN18UIExtraDataManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIExtraDataManager",
        "sigExtraDataMapAcknowledging",
        "",
        "QUuid",
        "uID",
        "sigExtraDataChange",
        "strKey",
        "strValue",
        "sigNotificationCenterAlignmentChange",
        "sigNotificationCenterOrderChange",
        "sigSettingsExpertModeChange",
        "sigLanguageChange",
        "strLanguage",
        "sigSelectorUIShortcutChange",
        "sigRuntimeUIShortcutChange",
        "sigRuntimeUIHostKeyCombinationChange",
        "sigToolLabelsVisibilityChange",
        "fVisible",
        "sigCloudProfileManagerRestrictionChange",
        "sigCloudConsoleManagerDataChange",
        "sigCloudConsoleManagerRestrictionChange",
        "sigDetailsCategoriesChange",
        "sigDetailsOptionsChange",
        "DetailsElementType",
        "enmType",
        "sigVisualStateChange",
        "uMachineID",
        "sigMenuBarConfigurationChange",
        "sigStatusBarConfigurationChange",
        "sigHidLedsSyncStateChange",
        "fEnabled",
        "sigScaleFactorChange",
        "sigScalingOptimizationTypeChange",
        "sigFontScaleFactorChanged",
        "iFontScaleFactor",
        "sigDisableHostScreenSaverStateChange",
        "fDisable",
        "sltExtraDataChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigExtraDataMapAcknowledging'
        QtMocHelpers::SignalData<void(const QUuid &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigExtraDataChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'sigNotificationCenterAlignmentChange'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigNotificationCenterOrderChange'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSettingsExpertModeChange'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigLanguageChange'
        QtMocHelpers::SignalData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'sigSelectorUIShortcutChange'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRuntimeUIShortcutChange'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRuntimeUIHostKeyCombinationChange'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigToolLabelsVisibilityChange'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'sigCloudProfileManagerRestrictionChange'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCloudConsoleManagerDataChange'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCloudConsoleManagerRestrictionChange'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDetailsCategoriesChange'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDetailsOptionsChange'
        QtMocHelpers::SignalData<void(DetailsElementType)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'sigVisualStateChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 26 },
        }}),
        // Signal 'sigMenuBarConfigurationChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 26 },
        }}),
        // Signal 'sigStatusBarConfigurationChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 26 },
        }}),
        // Signal 'sigHidLedsSyncStateChange'
        QtMocHelpers::SignalData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'sigScaleFactorChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 26 },
        }}),
        // Signal 'sigScalingOptimizationTypeChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 26 },
        }}),
        // Signal 'sigFontScaleFactorChanged'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'sigDisableHostScreenSaverStateChange'
        QtMocHelpers::SignalData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'sltExtraDataChange'
        QtMocHelpers::SlotData<void(const QUuid &, const QString &, const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 26 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIExtraDataManager, qt_meta_tag_ZN18UIExtraDataManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIExtraDataManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIExtraDataManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIExtraDataManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18UIExtraDataManagerE_t>.metaTypes,
    nullptr
} };

void UIExtraDataManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIExtraDataManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigExtraDataMapAcknowledging((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 1: _t->sigExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->sigNotificationCenterAlignmentChange(); break;
        case 3: _t->sigNotificationCenterOrderChange(); break;
        case 4: _t->sigSettingsExpertModeChange(); break;
        case 5: _t->sigLanguageChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->sigSelectorUIShortcutChange(); break;
        case 7: _t->sigRuntimeUIShortcutChange(); break;
        case 8: _t->sigRuntimeUIHostKeyCombinationChange(); break;
        case 9: _t->sigToolLabelsVisibilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->sigCloudProfileManagerRestrictionChange(); break;
        case 11: _t->sigCloudConsoleManagerDataChange(); break;
        case 12: _t->sigCloudConsoleManagerRestrictionChange(); break;
        case 13: _t->sigDetailsCategoriesChange(); break;
        case 14: _t->sigDetailsOptionsChange((*reinterpret_cast<std::add_pointer_t<DetailsElementType>>(_a[1]))); break;
        case 15: _t->sigVisualStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 16: _t->sigMenuBarConfigurationChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 17: _t->sigStatusBarConfigurationChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 18: _t->sigHidLedsSyncStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->sigScaleFactorChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 20: _t->sigScalingOptimizationTypeChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 21: _t->sigFontScaleFactorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->sigDisableHostScreenSaverStateChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->sltExtraDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DetailsElementType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigExtraDataMapAcknowledging, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & , const QString & , const QString & )>(_a, &UIExtraDataManager::sigExtraDataChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigNotificationCenterAlignmentChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigNotificationCenterOrderChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigSettingsExpertModeChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(QString )>(_a, &UIExtraDataManager::sigLanguageChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigSelectorUIShortcutChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigRuntimeUIShortcutChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigRuntimeUIHostKeyCombinationChange, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(bool )>(_a, &UIExtraDataManager::sigToolLabelsVisibilityChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigCloudProfileManagerRestrictionChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigCloudConsoleManagerDataChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigCloudConsoleManagerRestrictionChange, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)()>(_a, &UIExtraDataManager::sigDetailsCategoriesChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(DetailsElementType )>(_a, &UIExtraDataManager::sigDetailsOptionsChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigVisualStateChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigMenuBarConfigurationChange, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigStatusBarConfigurationChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(bool )>(_a, &UIExtraDataManager::sigHidLedsSyncStateChange, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigScaleFactorChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(const QUuid & )>(_a, &UIExtraDataManager::sigScalingOptimizationTypeChange, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(int )>(_a, &UIExtraDataManager::sigFontScaleFactorChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIExtraDataManager::*)(bool )>(_a, &UIExtraDataManager::sigDisableHostScreenSaverStateChange, 22))
            return;
    }
}

const QMetaObject *UIExtraDataManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIExtraDataManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIExtraDataManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UIExtraDataManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void UIExtraDataManager::sigExtraDataMapAcknowledging(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UIExtraDataManager::sigExtraDataChange(const QUuid & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void UIExtraDataManager::sigNotificationCenterAlignmentChange()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UIExtraDataManager::sigNotificationCenterOrderChange()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UIExtraDataManager::sigSettingsExpertModeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UIExtraDataManager::sigLanguageChange(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UIExtraDataManager::sigSelectorUIShortcutChange()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UIExtraDataManager::sigRuntimeUIShortcutChange()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void UIExtraDataManager::sigRuntimeUIHostKeyCombinationChange()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void UIExtraDataManager::sigToolLabelsVisibilityChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UIExtraDataManager::sigCloudProfileManagerRestrictionChange()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void UIExtraDataManager::sigCloudConsoleManagerDataChange()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void UIExtraDataManager::sigCloudConsoleManagerRestrictionChange()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void UIExtraDataManager::sigDetailsCategoriesChange()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void UIExtraDataManager::sigDetailsOptionsChange(DetailsElementType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void UIExtraDataManager::sigVisualStateChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void UIExtraDataManager::sigMenuBarConfigurationChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void UIExtraDataManager::sigStatusBarConfigurationChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void UIExtraDataManager::sigHidLedsSyncStateChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void UIExtraDataManager::sigScaleFactorChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void UIExtraDataManager::sigScalingOptimizationTypeChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void UIExtraDataManager::sigFontScaleFactorChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void UIExtraDataManager::sigDisableHostScreenSaverStateChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}
QT_WARNING_POP
